@@ -30,7 +30,9 @@ from bigml.api import get_status
 @step(r'I create a cluster$')
 def i_create_a_cluster(step):
     dataset = world.dataset.get('resource')
-    resource = world.api.create_cluster(dataset, {'seed': 'BigML tests'})
+    resource = world.api.create_cluster(
+        dataset, {'seed': 'BigML',
+                  'cluster_seed': 'BigML'})
     world.status = resource['code']
     assert world.status == HTTP_CREATED
     world.location = resource['location']
